@@ -2,6 +2,8 @@
 use crate::rules::non_critical_lints::no_console::NoConsoleConfig;
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::prefer_regex_literals::PreferRegexLiteralsConfig;
+#[cfg(feature = "non_critical_lints")]
+use crate::rules::non_critical_lints::quotes::QuotesConfig;
 use serde::{Deserialize, Serialize};
 use std::fmt::Debug;
 
@@ -54,4 +56,8 @@ pub struct LintConfig {
     #[cfg(feature = "non_critical_lints")]
     #[serde(default)]
     pub no_debugger: RuleConfig<()>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default)]
+    pub quotes: RuleConfig<QuotesConfig>,
 }
